@@ -57,7 +57,7 @@ FK on L<Interchange6::Schema::Result::ShipmentCarrier/shipment_carriers_id>.
 =cut
 
 column shipment_carriers_id =>
-  { data_type => "integer", is_foreign_key => 1 };
+  { data_type => "integer" };
 
 =head2 active
 
